@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _MULTIPLE_ACTIONS_H_
-#define _MULTIPLE_ACTIONS_H_
+#ifndef MULTIPLE_ACTIONS_H
+#define MULTIPLE_ACTIONS_H
 
 #include <QObject>
 #include <QString>
@@ -46,11 +46,11 @@ class MultipleActions : public LogModeAction
 public:
     MultipleActions(const QIcon &icon, const QString &text, QObject *parent);
 
-    virtual ~MultipleActions();
+    ~MultipleActions() override;
 
-    QList<QAction *> innerActions() Q_DECL_OVERRIDE;
+    QList<QAction *> innerActions() override;
 
-    QAction *actionMenu() Q_DECL_OVERRIDE;
+    QAction *actionMenu() override;
 
     /**
      * This method is not called addAction() to avoid name collision with
@@ -64,4 +64,4 @@ private:
     KActionMenu *action;
 };
 
-#endif // _MULTIPLE_ACTIONS_H_
+#endif // _MULTIPLE_ACTIONS_H
