@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _SYSLOG_ANALYZER_H_
-#define _SYSLOG_ANALYZER_H_
+#ifndef SYSLOG_ANALYZER_H
+#define SYSLOG_ANALYZER_H
 
 #include <QString>
 
@@ -40,14 +40,14 @@ class SyslogAnalyzer : public FileAnalyzer
 public:
     explicit SyslogAnalyzer(LogMode *logMode);
 
-    virtual ~SyslogAnalyzer();
+    ~SyslogAnalyzer() override;
 
-    LogViewColumns initColumns() Q_DECL_OVERRIDE;
+    LogViewColumns initColumns() override;
 
 protected:
-    LogFileReader *createLogFileReader(const LogFile &logFile) Q_DECL_OVERRIDE;
-    Analyzer::LogFileSortMode logFileSortMode() Q_DECL_OVERRIDE;
-    LogLine *parseMessage(const QString &logLine, const LogFile &originalFile) Q_DECL_OVERRIDE;
+    LogFileReader *createLogFileReader(const LogFile &logFile) override;
+    Analyzer::LogFileSortMode logFileSortMode() override;
+    LogLine *parseMessage(const QString &logLine, const LogFile &originalFile) override;
 
 private:
     inline QString undefinedHostName();
@@ -55,4 +55,4 @@ private:
     inline LogLine *undefinedLogLine(const QString &message, const LogFile &originalFile);
 };
 
-#endif // _SYSLOG_ANALYZER_H_
+#endif // _SYSLOG_ANALYZER_H
