@@ -20,15 +20,16 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _JOURNALD_NETWORK_ANALYZER_H_
-#define _JOURNALD_NETWORK_ANALYZER_H_
+#ifndef JOURNALD_NETWORK_ANALYZER_H
+#define JOURNALD_NETWORK_ANALYZER_H
 
 #include "journaldAnalyzer.h"
 #include "journaldTypes.h"
 
 using namespace JournaldTypes;
 
-#include <QtNetwork>
+#include <QNetworkAccessManager>
+#include <QNetworkReply>
 
 class JournaldNetworkAnalyzer : public JournaldAnalyzer
 {
@@ -45,7 +46,7 @@ public:
 
     virtual QStringList syslogIdentifiers() const;
 
-private slots:
+private Q_SLOTS:
     void httpFinished();
     void httpReadyRead();
     void httpError(QNetworkReply::NetworkError code);
@@ -76,4 +77,4 @@ private:
     QString m_filterName;
 };
 
-#endif // _JOURNALD_NETWORK_ANALYZER_H_
+#endif // _JOURNALD_NETWORK_ANALYZER_H
